@@ -21,7 +21,7 @@
 # http://code.google.com/p/pylast/
 
 __name__ = 'pylast'
-__version__ = '0.3.0b'
+__version__ = '0.3.1'
 __doc__ = 'A Python interface to Last.fm'
 __author__ = 'Amr Hassan'
 __email__ = 'amr.hassan@gmail.com'
@@ -551,6 +551,40 @@ class LibraryItem (object):
 		
 		return self.tagcount
 
+class PlayedTrack (object):
+	"""A track with a playback date."""
+	
+	def __init__(self, track, date, timestamp):
+		object.__init__(self)
+		
+		self.track = track
+		self.date = date
+		self.timestamp = timestamp
+	
+	def __repr__(self):
+		return repr(self.track) + " played at " + self.date
+	
+	def get_track(self):
+		"""Return the track."""
+		
+		return self.track
+	
+	def get_item(self):
+		"""Returns the played track. An alias to get_track()."""
+		
+		return self.get_track();
+	
+	def get_date(self):
+		"""Returns the playback date."""
+		
+		return self.date
+	
+	def get_timestamp(self):
+		"""Returns the unix timestamp of the playback date."""
+		
+		return self.timestamp
+	
+
 class Album(_BaseObject, _Taggable):
 	"""A Last.fm album."""
 	
@@ -1695,7 +1729,7 @@ class Track(_BaseObject, _Taggable):
 			return
 		
 		node = doc.getElementsByTagName("album")[0]
-		return Album(_extract(node, "artist"), _extract(node, "title"))
+		return Album(_extract(node, "artist"), _extract(node, "title"), *self.auth_data)
 	
 	def get_wiki_published_date(self):
 		"""Returns the date of publishing this version of the wiki."""
@@ -2137,7 +2171,10 @@ class User(_BaseObject):
 
 
 	def get_recent_tracks(self, limit = None):
-		"""Returns this user's recent listened-to tracks. """
+		"""Returns this user's recent listened-to tracks as
+		a sequence of PlayedTrack objects.
+		Use extract_items() with the return of this function to
+		get only a sequence of Track objects with no playback dates. """
 		
 		params = self._get_params()
 		if limit:
@@ -2147,13 +2184,15 @@ class User(_BaseObject):
 		
 		list = []
 		for track in doc.getElementsByTagName('track'):
-			title = _extract(track, 'name')
-			artist = _extract(track, 'artist')
+			title = _extract(track, "name")
+			artist = _extract(track, "artist")
+			date = _extract(track, "date")
+			timestamp = track.getElementsByTagName("date")[0].getAttribute("uts")
 			
 			if track.hasAttribute('nowplaying'):
 				continue	#to prevent the now playing track from sneaking in here
 				
-			list.append(Track(artist, title, *self.auth_data))
+			list.append(PlayedTrack(Track(artist, title, *self.auth_data), date, timestamp))
 		
 		return list
 	
